/*
 * Copyright(C) OASIS(R) 2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 */
package client_bjm;

import javax.jms.Message;
import javax.jms.Session;
import javax.jms.TextMessage;

import org.junit.Ignore;
import org.junit.Test;

import client.TestConfiguration;

/**
 * Client for BJM_4002_4_TestCase
 * 
 * If no operationSelector element is specified then SCA runtimes MUST use
 * operationSelector.jmsDefault as the default
 *
 * In this case we are testing the sub-case:
 * More than one operation in the interface;
 * No scaOperationName user property
 * No top-level XML element in the message body matching an operation name.
 * The selected operation name is "onMessage".
 */

public class BJM_4002_4_TestCase extends BaseJMSTestRunner {
	
	   protected TestConfiguration getTestConfiguration() {
	    	JMSTestConfiguration config = new JMSTestConfiguration();
	    	config.testName          = this.getClass().getSimpleName().substring(0, 10);
	    	config.input             = "BJM_4002_4 request message";
	    	config.output[0]         = "<?xml version=\"1.0\" encoding=\"UTF-8\"?><return>service5 onMessage invoked with BJM_4002_4 request message</return>";
	    	config.composite         = "Test_" + config.testName + ".composite";
	    	config.contributionNames = new String[] { "BJM_4002_4", "BJM_General", "BJM_General" + _Lang };
	        config.destinationName   = "TEST_BJM_4002_Queue";
	 
	    	return config;
	    }
	   
	    /**
	     * Create the request message.
	     * @param input - input string
	     * @param sess - the JMS session
	     * @return the request message.
	     * @throws Exception - if the JMS message exchange fails (e.g. the target service does not exist)
	     */
	    public Message createRequestMessage( String input, Session sess ) throws Exception {
	    	TextMessage textMsg = (TextMessage)super.createRequestMessage(input, sess);
	        textMsg.setText("<string>"+input+"</string>");
	        return textMsg;
	    }
	   
	    /**
	     * Dummy method to ensure that things work with JUnit 3 eg within Eclipse Ganymede
	     */
	    @Ignore
	    @Test
	    public void testFoo() throws Exception {  	
	    }

}  // end class BJM_4002_4_TestCase
