/*
 * Copyright(C) OASIS(R) 2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 */
package client_bjm;

import javax.jms.BytesMessage;
import javax.jms.Destination;
import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageProducer;
import javax.jms.Session;

import org.junit.Ignore;
import org.junit.Test;

import testClient.TestInvocation;
import client.TestConfiguration;

/**
 * Client for BJM_6012_TestCase
 * 
 * For an SCA reference with a JMS binding and bidirectional interface, when a request
 * message is sent as part of a one-way MEP the SCA runtime MUST set the destination
 * to which callback messages are to be sent as the JMSReplyTo destination in the
 * message it creates
 * 
 */
public class BJM_6012_TestCase extends NamedReplyJMSTestRunner {

    private Session sess;


	protected TestConfiguration getTestConfiguration() {
    	NamedReplyJMSTestConfiguration config = new NamedReplyJMSTestConfiguration();
    	config.testName 		 = this.getClass().getSimpleName().substring(0, 8);
    	config.input 		 	 = "request";
    	config.output[0] 		 = "JMSReplyTo is set";
    	config.composite 		 = "Test_" + config.testName + ".composite";
    	config.testServiceName 	 = "TestClient";
    	config.contributionNames = new String[] { "BJM_6012", "BJM_General", "BJM_General" + _Lang };
    	config.serviceInterface  = TestInvocation.class;
        config.destinationName   = "TEST_BJM_6012_Service_Queue";
        config.calloutDestinationName = "TEST_BJM_6012_Reference_Queue";
    	return config;
    }
    
    /**
     * Check the reply message.
     *
     * @param reply - the reply message
     * @return the output.
     * @throws Exception - if the JMS message exchange fails (e.g. the target service does not exist)
     */
    public String checkReplyMessage( Message reply ) throws Exception {
        Destination d = reply.getJMSReplyTo();
        
        if (d == null) {
        	return "JMSReplyTo is null";
        }
    	return "JMSReplyTo is set";
    }

    /**
     * Dummy method to ensure that things work with JUnit 3 eg within Eclipse Ganymede
     */
    @Ignore
    @Test
    public void testFoo() throws Exception {  	
    }
}  // end class BJM_6012_TestCase
