/*
 * Copyright(C) OASIS(R) 2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 */
package client_bjm;

import javax.jms.Message;
import javax.jms.Session;
import javax.jms.TextMessage;

import org.junit.Ignore;
import org.junit.Test;

import testClient.TestInvocation;
import client.TestConfiguration;

/**
 * Client for BJM_6015_2_TestCase
 * 
 * For an SCA service with a JMS binding, when a callback request message is sent for
 * either a one-way or request/response MEP, the SCA runtime MUST send the callback
 * request message to the callback destination.
 *  
 *  This is test for the scaCallbackDestination property identifying the callback destination
 */
public class BJM_6015_2_TestCase extends NamedReplyJMSTestRunner {

	protected TestConfiguration getTestConfiguration() {
    	NamedReplyJMSTestConfiguration config = new NamedReplyJMSTestConfiguration();
    	config.testName 		 = this.getClass().getSimpleName().substring(0, 8);
    	config.input 		 	 = "request";
    	config.output[0] 		 = "<?xml version=\"1.0\" encoding=\"UTF-8\"?><arg0>onewayOperation1 callback request</arg0>";
    	config.composite 		 = "Test_" + config.testName + ".composite";
    	config.testServiceName 	 = "TestClient";
    	config.contributionNames = new String[] { "BJM_6015", "BJM_General", "BJM_General" + _Lang };
    	config.serviceInterface  = TestInvocation.class;
        config.destinationName   = "TEST_BJM_6015_Service_Queue";
        config.calloutDestinationName = "TEST_BJM_6015_SCD_Prop_Queue";
    	return config;
    }

	@Override
    public Message createRequestMessage( String input, Session sess ) throws Exception {
    	TextMessage msg = (TextMessage) super.createRequestMessage(input, sess);
    	msg.setText(msg.getText().replace("operation1", "onewayOperation1"));
    	msg.setStringProperty("scaCallbackDestination", "jms:jndi:TEST_BJM_6015_SCD_Prop_Queue");
    	return msg;
    }
	
    /**
     * Dummy method to ensure that things work with JUnit 3 eg within Eclipse Ganymede
     */
    @Ignore
    @Test
    public void testFoo() throws Exception {  	
    }
}  // End class BJM_6015_2_TestCase
